%define libname %mklibname Rmath
# (tpg) really not needed
# for private copy in /usr/lib/R/share/perl/Text/DelimMatch.pm 
%global __provides_exclude KernSmooth.so|MASS.so|R_X11.so|class.so|cluster.so|foreign.so|grDevices.so|grid.so|internet.so|lapack.so|lattice.so|libRblas.so|libRlapack.so|methods.so|mgcv.so|nlme.so|nnet.so|rpart.so|spatial.so|splines.so|stats.so|survival.so|tcltk.so|tools.so|vfonts.so|perl\\\(R::.*\\\)
%global __requires_exclude libRblas.so|libRlapack.so|perl\\\(R::.*\\\)
%define _disable_ld_no_undefined 1
%ifarch %mips
%define use_java	0
%else
%define use_java	1
%endif

Summary:	A language for data analysis and graphics
Name:		R-base
Version:	4.4.0
Release:	%mkrel 1
License:	GPLv2+
Group:		Sciences/Mathematics
URL:		  https://www.r-project.org
Source0:	  https://cran.r-project.org/src/base/R-4/R-%{version}.tar.xz
Source1:        R-icons-png.tar.bz2
Source2:	  R.bash_completion.bz2
Patch0:		R-2.15.3-menu.patch

BuildRequires:	lib64pth-devel
BuildRequires:	glibc-static-devel
BuildRequires:	gcc-c++
BuildRequires:	cups-common
BuildRequires:	bzip2-devel
BuildRequires:	gcc-gfortran
BuildRequires:	gpm-devel
BuildRequires:	ncurses-devel
BuildRequires:	lib64readline-devel
BuildRequires:	lib64tk-devel
BuildRequires:	tcl
BuildRequires:	lib64tcl-devel
BuildRequires:	texinfo
BuildRequires:	texinfo-tex
BuildRequires:	texlive-dist
BuildRequires:  lib64x11-devel
BuildRequires:	png-devel
BuildRequires:	jpeg-devel
BuildRequires:	pcre-devel
BuildRequires:	bison
BuildRequires:	xdg-utils
%if %{use_java}
BuildRequires:	java-rpmbuild
%endif
BuildRequires:	paper-utils
BuildRequires:	cairo-devel
BuildRequires:	pango-devel
BuildRequires:	lib64tiff-devel
BuildRequires:	zip
BuildRequires:	gcc-objc
BuildRequires:	gcc-objc++
BuildRequires:	imake
BuildRequires:	gettext-devel
BuildRequires:	glibc-static-devel
BuildRequires:	pth-devel
BuildRequires:	lzma-devel
BuildRequires:	icu-devel
BuildRequires:	paper-utils
Requires:	tcl
Requires:	tk
Requires:	perl
Requires:	sed
Requires:	x11-font-adobe-100dpi
Requires:   lib64icu69
Provides:	R
Obsoletes:	R-recommended <= 1.5.1
Provides:	R-recommended

%description
`GNU S' - A language and environment for statistical computing and
graphics. R is similar to the S system, which was developed at Bell
Laboratories by John Chambers et al. It provides a wide variety of
statistical and graphical techniques (linear and nonlinear modelling,
statistical tests, time series analysis, classification, clustering, ...).

R is designed as a true computer language with control-flow
constructions for iteration and alternation, and it allows users to
add additional functionality by defining new functions. For
computationally intensive tasks, C, C++ and Fortran code can be linked
and called at run time.

%package -n %{libname}
Summary:	Standalone math library from the R project
Group:		System/Libraries

%description -n %{libname}
A standalone library of mathematical and statistical functions derived
from the R project.  This packages provides the shared libRmath library.

%package -n %{libname}-devel
Summary:	Standalone math library from the R project
Group:		Development/Libraries
Provides:	libRmath-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n %{libname}-devel
A standalone library of mathematical and statistical functions derived
from the R project.  This packages provides the static libRmath library
and header files.

%prep
%setup -qn R-%{version}
%autopatch -p1

%build
export R_BROWSER="$(type -p xdg-open)"
export R_PDFVIEWER="$(type -p xdg-open)"
export R_PRINTCMD="lpr"

export CFLAGS=$(echo "%{optflags}" | sed -e s/-ffast-math/-fno-fast-math/g )
export CFLAGS="%{optflags}"
export FFLAGS=$CFLAGS
export CXXFLAGS=$CFLAGS
export FCFLAGS=$CFLAGS
export OBJCFLAGS=$CFLAGS
export F77="gfortran"
%if %{use_java}
export JAVA_HOME="%{java_home}"
%endif
export FPICFLAGS=-fPIC
export CPICFLAGS=-fPIC
unset DISPLAY

%configure2_5x \
	--with-tcltk \
	--with-tcl-config=%{_libdir}/tclConfig.sh \
	--with-tk-config=%{_libdir}/tkConfig.sh \
	--with-cairo \
	--with-libpng \
	--with-jpeglib \
	--with-system-zlib \
	--with-system-bzlib \
	--with-system-pcre \
	--with-system-xz \
	--with-ICU \
	--with-readline \
	--enable-BLAS-shlib \
	--enable-threads=pth \
	--enable-R-profiling \
	--enable-R-shlib \
        --disable-lto

make %{?_smp_mflags}

pushd src/nmath/standalone
make %{?_smp_mflags}
popd

%make %{?_smp_mflags} pdf
%make %{?_smp_mflags} info

# DON'T comment "make check" below! If R doesn't pass the 'check' test
# then it is probably badly compiled, or there are problems with
# the compiler.
%check
TZ="Europe/Paris" LC_ALL=UTF-8 make check || (find -name "*.fail" | xargs cat ; exit 1)


%install
rm -rf %{buildroot}

#%makeinstall install-info rhome=%{buildroot}%{_libdir}/R
# N.B. don't use %%makeinstall because it sets prefix= which breaks Rscript
# mga#1434
%makeinstall_std install-info 

pushd src/nmath/standalone
%makeinstall \
    includedir=%{buildroot}%{_includedir} \
    libdir=%{buildroot}%{_libdir}
popd

mv doc/manual/*.pdf $RPM_BUILD_DIR/R-%{version} || :
# Add soft links (useful for TK gui)
for i in R-admin R-data refman R-exts R-FAQ R-intro R-lang; do
	ln -s %{_datadir}/doc/R-base/${i}.pdf %{buildroot}%{_libdir}/R/doc/manual/${i}.pdf
done

# Remove latex versions of help pages
rm -rf %{buildroot}%{_libdir}/R/library/*/latex/

# Get rid of buildroot in script
for i in %{buildroot}%{_libdir}/R/bin/R %{buildroot}%{_bindir}/R %{buildroot}%{_libdir}/pkgconfig/libR*.pc;
do
  sed -i "s|%{buildroot}||g" $i;
done

# Remove package indices. They are rebuilt by the postinstall script.
rm -f %{buildroot}%{_libdir}/R/doc/html/function.html
rm -f %{buildroot}%{_libdir}/R/doc/html/packages.html
rm -f %{buildroot}%{_libdir}/R/doc/html/search/index.txt

# Fix permissions
chmod 644 %{buildroot}%{_libdir}/R/library/MASS/scripts/*
chmod 755 %{buildroot}%{_libdir}/R/share/sh/echo.sh

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=R
Comment=A language for statistical computing
Exec=%{_bindir}/R --gui=tk
Terminal=true
Type=Application
Icon=Rlogo
Categories=Science;Math;X-MandrivaLinux-MoreApplications-Sciences-Mathematics
EOF

# add symlinks
ln -s %{_libdir}/R/lib/libR.so %{buildroot}/%{_libdir}/libR.so
ln -s %{_libdir}/R/lib/libRlapack.so %{buildroot}/%{_libdir}/libRlapack.so

# icons
mkdir -p %{buildroot}%{_iconsdir}
tar xjf %{SOURCE1} -C %{buildroot}%{_iconsdir}

# remove unpackaged files
rm -f %{buildroot}%{_infodir}/dir{,.old*}

# remove private perl libraries
rm -rf %{buildroot}%{_libdir}/R/share/perl/File
rm -rf %{buildroot}%{_libdir}/R/share/perl/Text

# (tpg) add bash completion file
mkdir -p %{buildroot}%{_sysconfdir}/bash_completion.d
bzcat %{SOURCE2} > %{buildroot}%{_sysconfdir}/bash_completion.d/R-base

%find_lang %{name}

%clean
rm -rf %{buildroot}

%post
%{update_menus}
%_install_info R-admin.info
%_install_info R-data.info
%_install_info R-exts.info
%_install_info R-FAQ.info
%_install_info R-intro.info
%_install_info R-lang.info
%{_bindir}/R CMD perl %{_libdir}/R/share/perl/build-help.pl --htmllist > /dev/null 2>&1
mkdir -p %{_libdir}/R/doc/html/search > /dev/null 2>&1
cat %{_libdir}/R/library/*/CONTENTS > %{_libdir}/R/doc/html/search/index.txt 2>/dev/null || :

%preun 
if [ $1 = 0 ]; then
rm -f %{_libdir}/R/doc/html/function.html \
 %{_libdir}/R/doc/html/packages.html \
 %{_libdir}/R/doc/html/search/index.txt
%_remove_install_info R-admin.info
%_remove_install_info R-data.info
%_remove_install_info R-exts.info
%_remove_install_info R-FAQ.info
%_remove_install_info R-intro.info
%_remove_install_info R-lang.info
fi

%postun
%{clean_menus}


%files
%defattr(-,root,root)
%doc README VERSION
###%doc R-admin.pdf R-data.pdf R-exts.pdf R-FAQ.pdf R-intro.pdf R-lang.pdf
%{_sysconfdir}/bash_completion.d/*
%{_bindir}/R
%{_bindir}/Rscript
%{_mandir}/*/*
%{_libdir}/R
%{_infodir}/*.info*
%{_iconsdir}/*.*
%{_liconsdir}/*.*
%{_miconsdir}/*.*
%{_datadir}/applications/*.desktop
%{_libdir}/pkgconfig/libR.pc

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/libRmath.so
%{_libdir}/libR.so
%{_libdir}/libRlapack.so

%files -n %{libname}-devel
%defattr(-,root,root)
%{_libdir}/libRmath.a
%{_includedir}/Rmath.h
%{_libdir}/pkgconfig/libRmath.pc



%changelog
* Thu Apr 25 2024 pp - 4.4.0-1pclos2024
- new version

* Sat Mar 02 2024 pp - 4.3.3-1pclos2024
- new version

* Mon Nov 06 2023 pp - 4.3.2-1pclos2023
- new version

* Thu Jun 22 2023 pp - 4.3.1-1pclos2023
- new version

* Fri Apr 21 2023 pp - 4.3.0-1pclos2023
- new version

* Thu Mar 16 2023 pp - 4.2.3-1pclos2023
- new version

* Tue Nov 01 2022 pp - 4.2.2-1pclos2022
- new version

* Sat Jul 02 2022 pp - 4.2.1-1pclos2022
- new version

* Fri Apr 22 2022 pp - 4.2.0-1pclos2022
- new version

* Sun Mar 20 2022 pp - 4.1.3-1pclos2022
- new version

* Thu Nov 04 2021 tex - 4.1.2-2pclos2021
- req lib64icu69 not lib64icu65 now

* Mon Nov 01 2021 pp <pp> 4.1.2-1pclos2021
- update

* Tue Aug 10 2021 pp <pp> 4.1.1-1pclos2021
- update

* Tue May 18 2021 pp <pp> 4.1.0-1pclos2021
- update

* Wed Mar 31 2021 pp <pp> 4.0.5-1pclos2021
- update

* Mon Feb 15 2021 pp <pp> 4.0.4-1pclos2021
- update

* Sat Oct 10 2020 pp <pp> 4.0.3-1pclos2020
- update

* Fri Jun 26 2020 pp <pp> 4.0.2-1pclos2020
- update

* Sun Jun 07 2020 pp <pp> 4.0.1-1pclos2020
- update
- added BR texlive-dist

* Fri Apr 24 2020 pp <pp> 4.0.0-1pclos2020
- update

* Mon Mar 09 2020 pp <pp> 3.6.3-1pclos2020
- update

* Wed Jan 08 2020 pp <pp> 3.6.2-1pclos2020
- update

* Tue Oct 08 2019 pp <pp> 3.6.1-2pclos2019
- updated icu-require

* Mon Oct 07 2019 pp <pp> 3.6.1-1pclos2019
- update

* Fri Apr 26 2019 pp <pp> 3.6.0-1pclos2019
- update

* Mon Mar 11 2019 pp <pp> 3.5.3-1pclos2019
- update

* Fri Feb 22 2019 pp <pp> 3.5.2-1pclos2019
- update

* Tue Jul 03 2018 pp <pp> 3.5.1-1pclos2018
- update

* Sun May 20 2018 pp <pp> 3.5.0-1pclos2018
- update

* Sat Mar 31 2018 pp <pp> 3.4.4-1pclos2018
- update

* Fri Dec 15 2017 pp <pp> 3.4.3-1pclos2017
- update

* Thu Oct 5 2017 pp <pp> 3.4.2-1pclos2017
- update
- changed to Require icu56

* Tue Jul 11 2017 woodhead <pp> 3.4.1-1pclos2017
- update
- added TZ="Europe/Paris" to please make check

* Sat Mar 11 2017 woodhead <pp> 3.3.3-1pclos2017
- update

* Thu Dec 22 2016 woodhead <pp> 3.3.2-1pclos2017
- update

* Sun Jul 24 2016 woodhead <pp> 3.3.1-1pclos2016
- update

* Tue Apr 26 2016 woodhead <pp> 3.2.5-1pclos2016
- update

* Wed Dec 23 2015 pp <pp> 3.2.3-1pclos2016
- update

* Sun Oct 11 2015 pp <pp> 3.2.2-1pclos2015
- update

* Tue May 26 2015 gseaman <galen.seaman at comcast.net> 3.2.0-1gseaman2015
- 3.2.0

* Sat Mar 28 2015 pinoc <vogtpet at gmail.com> 3.1.3-1pclos2015
- 3.1.3

* Sun Nov 02 2014 pinoc <vogtpet at gmail.com> 3.1.2-1pclos2014
- 3.1.2

